from src.datasets_metadata.table.datasetes_metadata_csv import DatasetMetadataSCV
from src.datasets_metadata.dict.datasetes_metadata_pickle import DatasetMetadataPickle

__author__ = "Lion Ben Nedava"
__email__ = "lionben89@gmail.com"
__version__ = "1.0.0"


def get_module_version():
    return __version__


__all__ = ["DatasetMetadataSCV", "DatasetMetadataPickle"]
