# from src.contact_sites_provider import ContactSitesProvider
# from src.contact_sites_result import ContactSitesResult

__author__ = "Lion Ben Nedava"
__email__ = "lionben89@gmail.com"
__version__ = "1.0.0"


def get_module_version():
    return __version__


# __all__ = ["ContactSitesProvider", "ContactSitesResult"]
